@@ -540,13 +540,19 @@ class BusServer (Bus):
             self.deactivate()
 
     def acceptClients(self):
+        import sys
+        if sys.platform == 'darwin':
+            self.__socket.settimeout(1.0)
         while self.__socket:
             self.__logger.info('Waiting for clients')
             try:
                 socket, addr = self.__socket.accept()
+                if sys.platform == 'darwin':
+                    socket.settimeout(None)
                 self.__logger.info('Accepted client %s', addr)
                 self.addConnection(BusConnection(socket_ = socket, isServer = True))
-            except:
+            except Exception, e:
+                self.__logger.error('Exception in acceptClients %s', e)
                 pass
 
     # Receiving notifications
@@ -648,7 +654,7 @@ class Connector(rsb.transport.Connector,
         elif serverString == 'auto':
             self.__server = 'auto'
         else:
-            raise TypeError, 'server option has to be "1", "true", "0", "false" or "auto", not %s' % serverString
+            raise TypeError, 'server option has to be "1", "true", "0", "false" or "auto", not "%s"' % serverString
 
     def __del__(self):
         if self.__active:
@@ -674,7 +680,7 @@ class Connector(rsb.transport.Connector,
                                    host, port)
                 self.__bus = getBusClientFor(host, port, self)
         else:
-            raise TypeError, 'server argument has to be True, False or "auto", not %s' % server
+            raise TypeError, 'server argument has to be True, False or "auto", not "%s"' % server
         self.__logger.info('Got %s', self.__bus)
         return self.__bus
 
